<?php
/**
 * The template for displaying meta box in page/post
 *
 * This adds Layout Options, Select Sidebar, Header Freatured Image Options, Single Page/Post Image Layout
 * This is only for the design purpose and not used to save any content
 *
 * @package Fotografie Blog Pro
 */


/**
 * Class to Add, Render and save metabox options
 *
 * @since Fotografie Blog Pro 1.0
 */
class Fotografie_Blog_Metabox {
    private $meta_box;

    /**
     * Constructor
     *
     * @since Fotografie Blog Pro 1.0
     *
     * @access public
     *
     */
    public function __construct( $meta_box_id, $meta_box_title, $post_type ) {

        $this->meta_box = array(
            'id'        => $meta_box_id,
            'title'     => $meta_box_title,
            'post_type' => $post_type,
        );

        // Add metaboxes.
        add_action( 'add_meta_boxes', array( $this, 'add' ) );

        add_action( 'save_post', array( $this, 'save' ) );

        add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_metabox_scripts' ) );
    }

    /**
     * Add Meta Box for multiple post types.
     *
     * @param [string] $post_type Post Type.
     */
    public function add( $post_type ) {
        if ( in_array( $post_type, $this->meta_box['post_type'] ) ) {
            add_meta_box( $this->meta_box['id'], $this->meta_box['title'], array( $this, 'show' ), $post_type );
        }
    }

    /**
     * Renders metabox
     */
    public function show() {
        global $post;

        $singular_image = array(
            'default' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'default',
                'label' => esc_html__( 'Default', 'fotografie-blog' ),
            ),
            'post-thumbnail' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'post-thumbnail',
                'label' => esc_html__( 'Featured Image', 'fotografie-blog' ),
            ),
            'full' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'full',
                'label' => esc_html__( 'Full Image', 'fotografie-blog' ),
            ),
            'fotografie-header-image' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'fotografie-blog-header-image',
                'label' => esc_html__( 'Header Image ( 1920x689 )', 'fotografie-blog' ),
            ),
            'fotografie-slider' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'fotografie-blog-slider',
                'label' => esc_html__( 'Slider Image', 'fotografie-blog' ),
            ),
            'disable' => array(
                'id'    => 'fotografie-blog-single-image',
                'value' => 'disable',
                'label' => esc_html__( 'Disable', 'fotografie-blog' ),
            ),
        );

        $header_image = array(
            'default' => array(
                'id'    => 'fotografie-blog-header-image',
                'value' => 'default',
                'label' => esc_html__( 'Default', 'fotografie-blog' ),
            ),
            'enable' => array(
                'id'    => 'fotografie-blog-header-image',
                'value' => 'enable',
                'label' => esc_html__( 'Enable', 'fotografie-blog' ),
            ),
            'disable' => array(
                'id'    => 'fotografie-blog-header-image',
                'value' => 'disable',
                'label' => esc_html__( 'Disable', 'fotografie-blog' ),
            ),
        );

        // Use nonce for verification.
        wp_nonce_field( basename( __FILE__ ), 'fotografie_blog_custom_meta_box_nonce' );

        // Begin the field table and loop.
        ?>
        <div id="fotografie-blog-ui-tabs" class="ui-tabs">
            <ul class="fotografie-blog-ui-tabs-nav" id="fotografie-blog-ui-tabs-nav">
                <li><a href="#frag2"><?php esc_html_e( 'Header Featured Image Options', 'fotografie-blog' ); ?></a></li>
                <li><a href="#frag3"><?php esc_html_e( 'Single Page/Post Image Layout ', 'fotografie-blog' ); ?></a></li>
            </ul>

            <div id="frag2" class="catch_ad_tabhead">
                <table class="form-table" width="100%">
                    <tbody>
                        <tr>
                            <?php
                            foreach ( $singular_image as $field ) {

                                $metaheader = get_post_meta( $post->ID, $field['id'], true );

                                if ( empty( $metaheader ) ) {
                                    $metaheader = 'default';
                                }
                            ?>

                            <td style="vertical-align: top;">
                                <label class="description">
                                    <input type="radio" name="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $metaheader ); ?>/>&nbsp;&nbsp;<?php echo esc_html( $field['label'] ); ?>
                                </label>
                            </td>

                            <?php
                            } // End foreach().
                            ?>
                        </tr>
                    </tbody>
                </table>
            </div>

            <div id="frag3" class="catch_ad_tabhead">
                <table class="form-table" width="100%">
                    <tbody>
                        <tr>
                            <?php
                            foreach ( $header_image as $field ) {

                                $metaheader = get_post_meta( $post->ID, $field['id'], true );

                                if ( empty( $metaheader ) ) {
                                    $metaheader = 'default';
                                }
                            ?>

                            <td style="vertical-align: top;">
                                <label class="description">
                                    <input type="radio" name="<?php echo esc_attr( $field['id'] ); ?>" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $metaheader ); ?>/>&nbsp;&nbsp;<?php echo esc_html( $field['label'] ); ?>
                                </label>
                            </td>

                            <?php
                            } // End foreach().
                            ?>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    <?php
    }

    /**
     * Save custom metabox data
     *
     * @action save_post
     *
     * @since Fotografie Blog Pro 1.0
     *
     * @access public
     */
    public function save( $post_id ) {
        global $post_type;

        $post_type_object = get_post_type_object( $post_type );

        if ( ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE )                      // Check Autosave
        || ( ! isset( $_POST['post_ID'] ) || $post_id != $_POST['post_ID'] )        // Check Revision
        || ( ! in_array( $post_type, $this->meta_box['post_type'] ) )                  // Check if current post type is supported.
        || ( ! check_admin_referer( basename( __FILE__ ), 'fotografie_blog_custom_meta_box_nonce') )    // Check nonce - Security
        || ( ! current_user_can( $post_type_object->cap->edit_post, $post_id ) ) )  // Check permission
        {
          return $post_id;
        }

        $value = $_POST['fotografie-blog-single-image'];

        if ( '' === $value || is_array( $value ) ) {
            return;
        } else {
            delete_post_meta( $post_id, 'fotografie-blog-single-image' );

            if ( ! update_post_meta( $post_id, 'fotografie-blog-single-image', sanitize_key( $value ) ) ) {
                add_post_meta( $post_id, 'fotografie-blog-single-image', sanitize_key( $value ), true );
            }
        }

        $value = $_POST['fotografie-blog-header-image'];

        if ( '' === $value || is_array( $value ) ) {
            return;
        } else {
            delete_post_meta( $post_id, 'fotografie-blog-header-image' );

            if ( ! update_post_meta( $post_id, 'fotografie-blog-header-image', sanitize_key( $value ) ) ) {
                add_post_meta( $post_id, 'fotografie-blog-header-image', sanitize_key( $value ), true );
            }
        }
    }

    public function enqueue_metabox_scripts( $hook ) {
        $allowed_pages = array( 'post-new.php', 'post.php' );

        // Bail if not on required page
        if ( ! in_array( $hook, $allowed_pages ) ) {
            return;
        }

        //Scripts
        wp_enqueue_script( 'fotografie-blog-metabox-script', trailingslashit( esc_url ( get_stylesheet_directory_uri() ) ) . 'inc/metabox/metabox.js', array( 'jquery', 'jquery-ui-tabs' ), '20180103' );

        //CSS Styles
        wp_enqueue_style( 'fotografie-blog-metabox-style', trailingslashit( esc_url ( get_stylesheet_directory_uri() ) ) . 'inc/metabox/metabox.css' );
    }
}

$clean_fotografie_metabox = new Fotografie_Blog_Metabox(
    'fotografie-blog-options',                   //metabox id
    esc_html__( 'Fotografie Blog Pro Options', 'fotografie-blog' ), //metabox title
    array( 'page', 'post' )             //metabox post types
);
